pub struct Client<M> { /* private fields */ }Expand description
The Client instance itself, which connects to the configured Server- Instance and manages all the underlying communication with ther Server
Implementations
Sourceimpl<M> Client<M>
impl<M> Client<M>
Sourcepub fn new_with_metrics(
server: Destination,
external_port: u16,
key: Vec<u8>,
metrics_collector: M,
) -> Self
pub fn new_with_metrics( server: Destination, external_port: u16, key: Vec<u8>, metrics_collector: M, ) -> Self
Behaves the same as the new implementation with the difference being
that you can specify and provide your own Metrics-Collector.