Message

Struct Message 

pub struct Message { /* private fields */ }
A single Message that is send between the Server and Client

Implementations

Source

impl Message

pub fn new(header: MessageHeader, data: Vec<u8>) -> Self

Creates a new Message with the given “raw” Data

pub fn serialize(&self, header: &mut [u8; 13]) -> &[u8]

Serializes the Message into a Vector of Bytes that can then be send over to the other side (Server or Client)

pub fn get_header(&self) -> &MessageHeader

The Header of this message

pub fn get_data(&self) -> &[u8]

The Raw underlying data that belong to do this message

pub fn is_eof(&self) -> bool

Checks if the messsage is marked as an EOF(End-Of-File)

This is useful for cases where the requests may be over, but the connections are not actually closed