pub enum Strategy {
Single(u16),
Multiple(Vec<u16>),
Dynamic(Option<Range<u16>>),
}Expand description
The Strategy used to determine if a given Port is valid according to the Strategy and its parameters
Variants
Single(u16)
Only the given Port is accepted and every other one is rejected
Multiple(Vec<u16>)
Accepts the Ports in the Vector
Dynamic(Option<Range<u16>>)
Accepts all the Ports in the Range
Implementations