pub struct UserCon { /* private fields */ }Expand description
This represents a single User-Connection and is used to send and receive Data for that one specific User
Implementations
Sourceimpl UserCon
impl UserCon
Sourcepub fn into_split(self) -> (OwnedReceiver, OwnedSender)
pub fn into_split(self) -> (OwnedReceiver, OwnedSender)
Splits the Connection into its owned (Reader, Writer)-Halfes, which allows you to use them more independantly of one another and enables you to send them to different Threads without having to use any extra sync between the Halfes