pub struct Server<M> { /* private fields */ }Expand description
Holds all information needed to creating and running a single Tunneler-Server
Implementations
Sourceimpl Server<Empty>
impl Server<Empty>
Sourcepub fn new(listen_port: u32, port_strategy: Strategy, key: Vec<u8>) -> Self
pub fn new(listen_port: u32, port_strategy: Strategy, key: Vec<u8>) -> Self
Creates a new Server-Instance from the given Data
Params:
- listen_port: The Port clients will connect to
- port_strategy: The Strategy to determine if a port a client wants to use is valid
- key: The Key/Password clients need to connect to the server
Sourceimpl<M> Server<M>where
M: Metrics,
impl<M> Server<M>where
M: Metrics,
Sourcepub fn new_metrics(
listen_port: u32,
port_strategy: Strategy,
key: Vec<u8>,
p_metrics: M,
) -> Self
pub fn new_metrics( listen_port: u32, port_strategy: Strategy, key: Vec<u8>, p_metrics: M, ) -> Self
Creates a new Server-Instance from the given Data
Params:
- listen_port: The Port clients will connect to
- port_strategy: The Strategy to determine if a port a client wants to use is valid
- key: The Key/Password clients need to connect to the server
- p_metrics: The Metrics-Collector to use
Sourcepub async fn listen(self) -> Result<(), ()>
pub async fn listen(self) -> Result<(), ()>
Actually starts the Server and starts listening for incoming Connections from both users and clients.
Behaviour
This function is not expected to return as all the connections will be handled internally or by other parts of the System, so this one can keep accepting new ones